# PyBioAnalyzer
Python codes for analyzing bioanalyzer files

# Requirements
Checked compatible with python3.7. Probably works in python >3.7.
- matplotlib
- scipy 1.2.1
- pandas

# Installation 
```
pip install pybioanalyzer
```
# Usage
```
pybioanalyzer --folder_name example/ --assay_type HS_DNA --min_lim 30 --max_lim 500 --disable_ladder
```
- result files must be export as csv format.
- Results.csv has to contain ladder information.

# Contribution
- Georg Urtel, Evgeniia Edeleva